diff --git a/indra/CMakeLists.txt b/indra/CMakeLists.txt
index e1e2f6f38a63b3bb33f09062687f88d956b530c7..5c82ebd2ba2523f771fadfc935c32b6c64d735bd 100644
--- a/indra/CMakeLists.txt
+++ b/indra/CMakeLists.txt
@@ -79,14 +79,14 @@ elseif (WINDOWS)
 endif (LINUX)
 
 add_subdirectory(${VIEWER_PREFIX}newview)
-add_dependencies(viewer secondlife-bin)
+add_dependencies(viewer alchemy-bin)
 
 add_subdirectory(${VIEWER_PREFIX}doxygen EXCLUDE_FROM_ALL)
 
 # sets the 'startup project' for debugging from visual studio.
 set_property(
     DIRECTORY ${VIEWER_PREFIX}
-    PROPERTY VS_STARTUP_PROJECT secondlife-bin
+    PROPERTY VS_STARTUP_PROJECT alchemy-bin
     )
 
 if (LL_TESTS)
diff --git a/indra/copy_win_scripts/start-client.py b/indra/copy_win_scripts/start-client.py
index 5699f5273f4b88b337d15139262a753bd3c3a151..bcc99a49b0d5fa5a096dbfce536a081874a7141a 100755
--- a/indra/copy_win_scripts/start-client.py
+++ b/indra/copy_win_scripts/start-client.py
@@ -56,7 +56,7 @@ def start_client(grid, slurl, build_config, my_args):
     f = open("start-client.log", "w")
     print >>f, "Viewer startup arguments:"
     llstart.start("viewer", "../../newview", 
-        "%s/newview/%s/secondlife-bin.exe" % (build_path, build_config),
+        "%s/newview/%s/alchemy-bin.exe" % (build_path, build_config),
         viewer_args, f)
     f.close()
 
diff --git a/indra/fix-incredibuild.py b/indra/fix-incredibuild.py
index 98f16e9d97ad8af4e22d93d97988af934a255b9e..6a2c8f17078a4a4568a5b9d56fb2abffb4ebd5dd 100755
--- a/indra/fix-incredibuild.py
+++ b/indra/fix-incredibuild.py
@@ -42,13 +42,13 @@ def main():
                  '*.ilk','*.lib','*.obj','*.ib_pdb_index']
     pch_types = ['*.pch']
     delete_file_types("build-vc80/newview/Release", build_types)
-    delete_file_types("build-vc80/newview/secondlife-bin.dir/Release/", 
+    delete_file_types("build-vc80/newview/alchemy-bin.dir/Release/", 
                       pch_types)
     delete_file_types("build-vc80/newview/RelWithDebInfo", build_types)
-    delete_file_types("build-vc80/newview/secondlife-bin.dir/RelWithDebInfo/", 
+    delete_file_types("build-vc80/newview/alchemy-bin.dir/RelWithDebInfo/", 
                       pch_types)
     delete_file_types("build-vc80/newview/Debug", build_types)
-    delete_file_types("build-vc80/newview/secondlife-bin.dir/Debug/", 
+    delete_file_types("build-vc80/newview/alchemy-bin.dir/Debug/", 
                       pch_types)
 
 
diff --git a/indra/llcommon/tests/llallocator_heap_profile_test.cpp b/indra/llcommon/tests/llallocator_heap_profile_test.cpp
index 44a9705803c1e029125f6e0eaaad326ca1c6f73b..554fba9f877704621cf9492c117feaadff957086 100644
--- a/indra/llcommon/tests/llallocator_heap_profile_test.cpp
+++ b/indra/llcommon/tests/llallocator_heap_profile_test.cpp
@@ -106,7 +106,7 @@ char const * const llallocator_heap_profile_data::sample_win_profile =
 "277152: 82862770 [621961: 168503640] @        2        3        3        7       21       32       87\n"
 "\n"
 "MAPPED_LIBRARIES:\n"
-"00400000-02681000 r-xp 00000000 00:00 0           c:\\proj\\tcmalloc-eval-9\\indra\\build-vc80\\newview\\RelWithDebInfo\\secondlife-bin.exe\n"
+"00400000-02681000 r-xp 00000000 00:00 0           c:\\proj\\tcmalloc-eval-9\\indra\\build-vc80\\newview\\RelWithDebInfo\\alchemy-bin.exe\n"
 "77280000-773a7000 r-xp 00000000 00:00 0           C:\\Windows\\system32\\ntdll.dll\n"
 "76df0000-76ecb000 r-xp 00000000 00:00 0           C:\\Windows\\system32\\kernel32.dll\n"
 "76000000-76073000 r-xp 00000000 00:00 0           C:\\Windows\\system32\\comdlg32.dll\n"
diff --git a/indra/newview/CMakeLists.txt b/indra/newview/CMakeLists.txt
index f4c1109aa642ec5cbf1117cc9c4a15db801c50d3..af969a52dee9ac11ee03bfdb935015d05c213535 100644
--- a/indra/newview/CMakeLists.txt
+++ b/indra/newview/CMakeLists.txt
@@ -745,7 +745,7 @@ set(viewer_SOURCE_FILES
     rlvui.cpp
     )
 
-set(VIEWER_BINARY_NAME "secondlife-bin" CACHE STRING
+set(VIEWER_BINARY_NAME "alchemy-bin" CACHE STRING
     "The name of the viewer executable to create.")
 
 set(viewer_HEADER_FILES
@@ -1786,7 +1786,7 @@ if (WINDOWS)
         # *TODO -reenable this once we get server usage sorted out
         LINK_FLAGS "/debug /NODEFAULTLIB:LIBCMT /SUBSYSTEM:WINDOWS /LARGEADDRESSAWARE"
         LINK_FLAGS_DEBUG "/NODEFAULTLIB:\"LIBCMT;LIBCMTD;MSVCRT\" /INCREMENTAL:NO /LARGEADDRESSAWARE"
-        LINK_FLAGS_RELEASE "/MAP\"secondlife-bin.MAP\" /OPT:REF /LARGEADDRESSAWARE"
+        LINK_FLAGS_RELEASE "/MAP\"alchemy-bin.MAP\" /OPT:REF /LARGEADDRESSAWARE"
         )
 
     if(USE_PRECOMPILED_HEADERS)
@@ -2282,8 +2282,8 @@ if (PACKAGE AND (RELEASE_CRASH_REPORTING OR NON_RELEASE_CRASH_REPORTING) AND VIE
     endif (DARWIN)
     if (LINUX)
       list(APPEND SYMBOL_SEARCH_DIRS "${CMAKE_CURRENT_BINARY_DIR}/packaged")
-      set(VIEWER_EXE_GLOBS "do-not-directly-run-secondlife-bin SLPlugin")
-      set(VIEWER_EXE_GLOBS "do-not-directly-run-secondlife-bin")
+      set(VIEWER_EXE_GLOBS "do-not-directly-run-alchemy-bin SLPlugin")
+      set(VIEWER_EXE_GLOBS "do-not-directly-run-alchemy-bin")
       set(VIEWER_LIB_GLOB "*${CMAKE_SHARED_MODULE_SUFFIX}*")
       set(VIEWER_COPY_MANIFEST copy_l_viewer_manifest)
     endif (LINUX)
@@ -2336,8 +2336,8 @@ if (PACKAGE AND (RELEASE_CRASH_REPORTING OR NON_RELEASE_CRASH_REPORTING) AND VIE
           "${VIEWER_SYMBOL_FILE_CYGWIN}"
           "-C"
           "${PARENT_DIRECTORY_CYGWIN}"
-          "secondlife-bin.pdb"
-        DEPENDS "${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_CFG_INTDIR}/secondlife-bin.pdb"
+          "alchemy-bin.pdb"
+        DEPENDS "${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_CFG_INTDIR}/alchemy-bin.pdb"
         COMMENT "Packing viewer PDB into ${VIEWER_SYMBOL_FILE_CYGWIN}"
         )
       add_custom_target(generate_symbols DEPENDS "${VIEWER_SYMBOL_FILE}" ${VIEWER_BINARY_NAME})
diff --git a/indra/newview/linux_tools/wrapper.sh b/indra/newview/linux_tools/wrapper.sh
index c23401d5a661fd954536fadf9c9b8fa0c7da3779..5b348d97f328144a8f8c580c343385e490683bc7 100755
--- a/indra/newview/linux_tools/wrapper.sh
+++ b/indra/newview/linux_tools/wrapper.sh
@@ -135,7 +135,7 @@ done
 # Don't quote $LL_WRAPPER because, if empty, it should simply vanish from the
 # command line. But DO quote "${ARGS[@]}": preserve separate args as
 # individually quoted.
-$LL_WRAPPER bin/do-not-directly-run-secondlife-bin "${ARGS[@]}"
+$LL_WRAPPER bin/do-not-directly-run-alchemy-bin "${ARGS[@]}"
 LL_RUN_ERR=$?
 
 # Handle any resulting errors
@@ -147,7 +147,7 @@ if [ $LL_RUN_ERR -ne 0 ]; then
 		cat << EOFMARKER
 You are running the Second Life Viewer on a x86_64 platform.  The
 most common problems when launching the Viewer (particularly
-'bin/do-not-directly-run-secondlife-bin: not found' and 'error while
+'bin/do-not-directly-run-alchemy-bin: not found' and 'error while
 loading shared libraries') may be solved by installing your Linux
 distribution's 32-bit compatibility packages.
 For example, on Ubuntu and other Debian-based Linuxes you might run:
diff --git a/indra/newview/secondlife-i686.supp b/indra/newview/secondlife-i686.supp
index 863c8364ab84779d9348ec1fdb6aae21bb02b08d..2e97a1e0b153cb13987e2443780b9c6a177fb0a4 100755
--- a/indra/newview/secondlife-i686.supp
+++ b/indra/newview/secondlife-i686.supp
@@ -34,7 +34,7 @@
 #   (if you have one), so that the viewer will use the system's
 #   libstdc++.
 # - After you build the viewer, replace the stripped
-#   do-not-directly-run-secondlife-bin binary with an unstripped copy.
+#   do-not-directly-run-alchemy-bin binary with an unstripped copy.
 
 # Mozilla noise.
 
diff --git a/indra/newview/viewer_manifest.py b/indra/newview/viewer_manifest.py
index 6f14cd64d16430720a6a27d38a05b60b3a47cfe9..f3ae6494e587aec9e83ee124696c8c23ce83146c 100755
--- a/indra/newview/viewer_manifest.py
+++ b/indra/newview/viewer_manifest.py
@@ -483,8 +483,8 @@ def construct(self):
         debpkgdir = os.path.join(pkgdir, "lib", "debug")
 
         if self.is_packaging_viewer():
-            # Find secondlife-bin.exe in the 'configuration' dir, then rename it to the result of final_exe.
-            self.path(src='%s/secondlife-bin.exe' % self.args['configuration'], dst=self.final_exe())
+            # Find alchemy-bin.exe in the 'configuration' dir, then rename it to the result of final_exe.
+            self.path(src='%s/alchemy-bin.exe' % self.args['configuration'], dst=self.final_exe())
 
             with self.prefix(src=os.path.join(pkgdir, "VMP")):
                 # include the compiled launcher scripts so that it gets included in the file_list
@@ -774,7 +774,7 @@ def package_finish(self):
             engage_registry="SetRegView 32"
             program_files=""
 
-        tempfile = "secondlife_setup_tmp.nsi"
+        tempfile = "alchemy_setup_tmp.nsi"
         # the following replaces strings in the nsi template
         # it also does python-style % substitution
         self.replace_in("installers/windows/installer_template.nsi", tempfile, {
@@ -1372,7 +1372,7 @@ def construct(self):
             self.path("install.sh")
 
         with self.prefix(dst="bin"):
-            self.path("secondlife-bin","do-not-directly-run-secondlife-bin")
+            self.path("alchemy-bin","do-not-directly-run-alchemy-bin")
             self.path("../linux_crash_logger/linux-crash-logger","linux-crash-logger.bin")
             self.path2basename("../llplugin/slplugin", "SLPlugin") 
             #this copies over the python wrapper script, associated utilities and required libraries, see SL-321, SL-322 and SL-323